:mod:`kwant` -- Top level package
=================================

.. module:: kwant

The top-level Kwant package serves as a container for sub-packages and does not
have any functions of its own.  For convenience, short names are provided for a
few widely used objects from the sub-packages:

.. currentmodule:: kwant.builder

From `kwant.builder`
--------------------
.. autosummary::

   Builder
   HoppingKind

.. currentmodule:: kwant.lattice

From `kwant.lattice`
--------------------
.. autosummary::

   TranslationalSymmetry

.. currentmodule:: kwant.plotter

From `kwant.plotter`
--------------------

.. autosummary::

   plot

.. currentmodule:: kwant.solvers.default

From `kwant.solvers.default`
----------------------------
.. autosummary::

   greens_function
   ldos
   smatrix
   wave_function

Version information
-------------------
The version of Kwant is available under the name ``__version__``.
